# Operator SDK Manager

![coverage](https://img.shields.io/codecov/c/gh/jharmison-redhat/osdk-manager) ![build](https://img.shields.io/travis/com/jharmison-redhat/osdk-manager) ![downloads](https://img.shields.io/pypi/dm/osdk-manager)

A python wrapper around the [Operator SDK](https://github.com/operator-framework/operator-sdk) and [Operator Package Manager](https://github.com/operator-framework/operator-registry) to make it easier to build CI workflows around release and versioning of an operator, operator bundle, and operator registry.

## Download

This package is published on PyPi as [osdk-manager](https://pypi.org/project/osdk-manager/). You can install it with `pip install osdk-manager`.

## Use

For detailed instructions on use, please refer to the embedded documentation in the CLI. Once installed, you can run `osdk-manager --help` to see a list of commands.
